@@ -22,17 +22,17 @@
 #include <tqsignalmapper.h>
 #include <tqwhatsthis.h>
 
-#include <kaboutapplication.h>
-#include <kaboutkde.h>
-#include <kmessagebox.h>
-#include <kconfigdialog.h>
+#include <tdeaboutapplication.h>
+#include <tdeabouttde.h>
+#include <tdemessagebox.h>
+#include <tdeconfigdialog.h>
 #include <kiconloader.h>
-#include <kwin.h>
+#include <twin.h>
 #include <dcopref.h>
 
 MainWindow::MainWindow(TQWidget * parent, const char * name) :
         DCOPObject("DCOPInterface"),
-        KMainWindow(parent, name, TQt::WStyle_Customize | TQt::WStyle_NoBorder),
+        TDEMainWindow(parent, name, TQt::WStyle_Customize | TQt::WStyle_NoBorder),
         step(0)
 {
     first_run_dialog = 0;
@@ -43,7 +43,7 @@ MainWindow::MainWindow(TQWidget * parent, const char * name) :
     background_changed = false;
     use_translucency = false;
 
-    KConfig config(CONFIG_FILE);
+    TDEConfig config(CONFIG_FILE);
 
     back_widget = new TQWidget(this);
     widgets_stack = new TQWidgetStack(this);
@@ -66,7 +66,7 @@ MainWindow::MainWindow(TQWidget * parent, const char * name) :
         Settings::setSkin("default");
 
     // Initialize access key.
-    global_key = new KGlobalAccel(TQT_TQOBJECT(this));
+    global_key = new TDEGlobalAccel(TQT_TQOBJECT(this));
     global_key->insert("AccessKey", i18n("Open/Retract Yakuake"),
                        i18n("Slides the Yakuake window in and out"),
                        Key_F12, 0, TQT_TQOBJECT(this), TQT_SLOT(slotToggleState()));
@@ -77,65 +77,65 @@ MainWindow::MainWindow(TQWidget * parent, const char * name) :
 
 
     // Initialize shortcuts.
-    KAction* action;
+    TDEAction* action;
 
-    KShortcut shortcut(TQt::CTRL+TQt::ALT+TQt::Key_N);
-    shortcut.append(KShortcut(TQt::CTRL+TQt::SHIFT+TQt::Key_N));
-    action = new KAction(i18n("New Session"), SmallIcon("tab_new"), shortcut,
+    TDEShortcut shortcut(TQt::CTRL+TQt::ALT+TQt::Key_N);
+    shortcut.append(TDEShortcut(TQt::CTRL+TQt::SHIFT+TQt::Key_N));
+    action = new TDEAction(i18n("New Session"), SmallIcon("tab_new"), shortcut,
                               TQT_TQOBJECT(this), TQT_SLOT(slotAddSession()),
                               actionCollection(), "add_tab");
 
-    action = new KAction(i18n("Two Terminals,Qt::Horizontal"), SmallIcon("tab_new"),
+    action = new TDEAction(i18n("Two Terminals, Horizontal"), SmallIcon("tab_new"),
                               0, TQT_TQOBJECT(this), TQT_SLOT(slotAddSessionTwoVertical()),
                               actionCollection(), "add_tab_twohorizontal");
 
-    action = new KAction(i18n("Two Terminals,Qt::Vertical"), SmallIcon("tab_new"),
+    action = new TDEAction(i18n("Two Terminals, Vertical"), SmallIcon("tab_new"),
                               0, TQT_TQOBJECT(this), TQT_SLOT(slotAddSessionTwoHorizontal()),
                               actionCollection(), "add_tab_twovertical");
 
-    action = new KAction(i18n("Four Terminals, Quad"), SmallIcon("tab_new"),
+    action = new TDEAction(i18n("Four Terminals, Quad"), SmallIcon("tab_new"),
                               0, TQT_TQOBJECT(this), TQT_SLOT(slotAddSessionQuad()),
                               actionCollection(), "add_tab_quad");
 
-    action = new KAction(i18n("Go to Next Terminal"), SmallIcon("next"),
+    action = new TDEAction(i18n("Go to Next Terminal"), SmallIcon("go-next"),
                               "Ctrl+Shift+Up", TQT_TQOBJECT(this), TQT_SLOT(slotFocusNextSplit()),
                               actionCollection(), "focus_next_terminal");
 
-    action = new KAction(i18n("Go to Previous Terminal"), SmallIcon("previous"),
+    action = new TDEAction(i18n("Go to Previous Terminal"), SmallIcon("go-previous"),
                               "Ctrl+Shift+Down", TQT_TQOBJECT(this), TQT_SLOT(slotFocusPreviousSplit()),
                               actionCollection(), "focus_previous_terminal");
 
-    action = new KAction(i18n("Paste"), SmallIcon("editpaste"), SHIFT+Key_Insert,
+    action = new TDEAction(i18n("Paste"), SmallIcon("edit-paste"), SHIFT+Key_Insert,
                               TQT_TQOBJECT(this), TQT_SLOT(slotPasteClipboard()),
                               actionCollection(), "paste_clipboard");
 
-    action = new KAction(i18n("Paste Selection"), SmallIcon("editpaste"),
+    action = new TDEAction(i18n("Paste Selection"), SmallIcon("edit-paste"),
                               CTRL+SHIFT+Key_Insert, TQT_TQOBJECT(this), TQT_SLOT(slotPasteSelection()),
                               actionCollection(), "paste_selection");
 
-    action = new KAction(i18n("Rename Session..."), SmallIcon("edit"),
+    action = new TDEAction(i18n("Rename Session..."), SmallIcon("edit"),
                               "Alt+Ctrl+S", TQT_TQOBJECT(this), TQT_SLOT(slotInteractiveRename()),
                               actionCollection(), "edit_name");
 
-    action = new KAction(i18n("Increase Width"), SmallIcon("viewmag+"),
+    action = new TDEAction(i18n("Increase Width"), SmallIcon("zoom-in"),
                               "Alt+Shift+Right", TQT_TQOBJECT(this), TQT_SLOT(slotIncreaseSizeW()),
                               actionCollection(), "increasew");
-    action = new KAction(i18n("Decrease Width"), SmallIcon("viewmag-"),
+    action = new TDEAction(i18n("Decrease Width"), SmallIcon("zoom-out"),
                               "Alt+Shift+Left", TQT_TQOBJECT(this), TQT_SLOT(slotDecreaseSizeW()),
                               actionCollection(), "decreasew");
-    action = new KAction(i18n("Increase Height"), SmallIcon("viewmag+"),
+    action = new TDEAction(i18n("Increase Height"), SmallIcon("zoom-in"),
                               "Alt+Shift+Down", TQT_TQOBJECT(this), TQT_SLOT(slotIncreaseSizeH()),
                               actionCollection(), "increaseh");
-    action = new KAction(i18n("Decrease Height"), SmallIcon("viewmag-"),
+    action = new TDEAction(i18n("Decrease Height"), SmallIcon("zoom-out"),
                               "Alt+Shift+Up", TQT_TQOBJECT(this), TQT_SLOT(slotDecreaseSizeH()),
                               actionCollection(), "decreaseh");
 
-    action = new KAction(i18n("Configure Global Shortcuts..."),
+    action = new TDEAction(i18n("Configure Global Shortcuts..."),
                               SmallIcon("configure_shortcuts"), 0,
                               TQT_TQOBJECT(this), TQT_SLOT(slotSetAccessKey()),
                               actionCollection(), "global_shortcuts");
 
-    action = new KAction(i18n("Quit"), SmallIcon("exit"), 0, TQT_TQOBJECT(this),
+    action = new TDEAction(i18n("Quit"), SmallIcon("system-log-out"), 0, TQT_TQOBJECT(this),
                               TQT_SLOT(close()), actionCollection(), "quit");
 
     KStdAction::keyBindings(TQT_TQOBJECT(this), TQT_SLOT(slotSetControlKeys()), actionCollection());
@@ -152,47 +152,47 @@ MainWindow::MainWindow(TQWidget * parent, const char * name) :
     createTitleBar();
     createTabsBar();
 
-    action = new KAction(i18n("Go to Next Session"), SmallIcon("next"),
+    action = new TDEAction(i18n("Go to Next Session"), SmallIcon("go-next"),
                               "Shift+Right", TQT_TQOBJECT(tab_bar), TQT_SLOT(slotSelectNextItem()),
                               actionCollection(), "next_tab");
-    action = new KAction(i18n("Go to Previous Session"), SmallIcon("previous"),
+    action = new TDEAction(i18n("Go to Previous Session"), SmallIcon("go-previous"),
                               "Shift+Left", TQT_TQOBJECT(tab_bar), TQT_SLOT(slotSelectPreviousItem()),
                               actionCollection(), "previous_tab");
 
-    action = new KAction(i18n("Move Session Left"), SmallIcon("back"),
+    action = new TDEAction(i18n("Move Session Left"), SmallIcon("back"),
                               "Ctrl+Shift+Left", TQT_TQOBJECT(tab_bar), TQT_SLOT(slotMoveItemLeft()),
                               actionCollection(), "move_tab_left");
 
-    action = new KAction(i18n("Move Session Right"), SmallIcon("forward"),
+    action = new TDEAction(i18n("Move Session Right"), SmallIcon("forward"),
                               "Ctrl+Shift+Right", TQT_TQOBJECT(tab_bar), TQT_SLOT(slotMoveItemRight()),
                               actionCollection(), "move_tab_right");
 
-    remove_tab_action = new KAction(i18n("Close Session"), SmallIcon("fileclose"), 0,
+    remove_tab_action = new TDEAction(i18n("Close Session"), SmallIcon("window-close"), 0,
                                     TQT_TQOBJECT(this), 0, actionCollection(), "remove_tab");
-    connect(remove_tab_action, TQT_SIGNAL(activated(KAction::ActivationReason, TQt::ButtonState)),
-        TQT_TQOBJECT(this), TQT_SLOT(slotHandleRemoveSession(KAction::ActivationReason, TQt::ButtonState)));
+    connect(remove_tab_action, TQT_SIGNAL(activated(TDEAction::ActivationReason, TQt::ButtonState)),
+        TQT_TQOBJECT(this), TQT_SLOT(slotHandleRemoveSession(TDEAction::ActivationReason, TQt::ButtonState)));
 
-    split_horiz_action = new KAction(i18n("Split TerminalQt::Horizontally"), SmallIcon("view_top_bottom"),
+    split_horiz_action = new TDEAction(i18n("Split Terminal Horizontally"), SmallIcon("view_top_bottom"),
                                      CTRL+SHIFT+Key_T, TQT_TQOBJECT(this), 0, actionCollection(), "split_horizontally");
-    connect(split_horiz_action, TQT_SIGNAL(activated(KAction::ActivationReason, TQt::ButtonState)),
-        TQT_TQOBJECT(this), TQT_SLOT(slotHandleVerticalSplit(KAction::ActivationReason, TQt::ButtonState)));
+    connect(split_horiz_action, TQT_SIGNAL(activated(TDEAction::ActivationReason, TQt::ButtonState)),
+        TQT_TQOBJECT(this), TQT_SLOT(slotHandleVerticalSplit(TDEAction::ActivationReason, TQt::ButtonState)));
 
-    split_vert_action = new KAction(i18n("Split TerminalQt::Vertically"), SmallIcon("view_left_right"),
+    split_vert_action = new TDEAction(i18n("Split Terminal Vertically"), SmallIcon("view_left_right"),
                                     CTRL+SHIFT+Key_L, TQT_TQOBJECT(this), 0, actionCollection(), "split_vertically");
-    connect(split_vert_action, TQT_SIGNAL(activated(KAction::ActivationReason, TQt::ButtonState)),
-        TQT_TQOBJECT(this), TQT_SLOT(slotHandleHorizontalSplit(KAction::ActivationReason, TQt::ButtonState)));
+    connect(split_vert_action, TQT_SIGNAL(activated(TDEAction::ActivationReason, TQt::ButtonState)),
+        TQT_TQOBJECT(this), TQT_SLOT(slotHandleHorizontalSplit(TDEAction::ActivationReason, TQt::ButtonState)));
 
-    remove_term_action = new KAction(i18n("Close Terminal"), SmallIcon("view_remove"),
+    remove_term_action = new TDEAction(i18n("Close Terminal"), SmallIcon("view_remove"),
                                      CTRL+SHIFT+Key_R, TQT_TQOBJECT(this), 0, actionCollection(), "remove_terminal");
-    connect(remove_term_action, TQT_SIGNAL(activated(KAction::ActivationReason, TQt::ButtonState)),
-        TQT_TQOBJECT(this), TQT_SLOT(slotHandleRemoveTerminal(KAction::ActivationReason, TQt::ButtonState)));
+    connect(remove_term_action, TQT_SIGNAL(activated(TDEAction::ActivationReason, TQt::ButtonState)),
+        TQT_TQOBJECT(this), TQT_SLOT(slotHandleRemoveTerminal(TDEAction::ActivationReason, TQt::ButtonState)));
 
     TQSignalMapper* tab_selection_mapper = new TQSignalMapper(TQT_TQOBJECT(this));
     connect(tab_selection_mapper, TQT_SIGNAL(mapped(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSelectTabPosition(int)));
 
     for (uint i = 1; i <= 12; ++i)
     {
-        KAction* tab_selection_action = new KAction(i18n("Switch to Session %1").arg(i), 0, 0,
+        TDEAction* tab_selection_action = new TDEAction(i18n("Switch to Session %1").arg(i), 0, 0,
             tab_selection_mapper, TQT_SLOT(map()), actionCollection(), TQString("go_to_tab_%1").arg(i).local8Bit());
         tab_selection_mapper->setMapping(tab_selection_action, i-1);
     }
@@ -324,7 +324,7 @@ void MainWindow::showPopup(const TQString& text, int time)
 {
     /* Show a passive popup with the given text. */
 
-    popup.setView(i18n("Yakuake Notification"), text, KApplication::kApplication()->miniIcon());
+    popup.setView(i18n("Yakuake Notification"), text, TDEApplication::kApplication()->miniIcon());
     popup.setTimeout(time);
     popup.show();
 }
@@ -377,9 +377,9 @@ void MainWindow::slotRemoveSession(int session_id)
     sessions_stack[session_id]->deleteLater();
 }
 
-void MainWindow::slotHandleRemoveSession(KAction::ActivationReason reason, TQt::ButtonState /* state */)
+void MainWindow::slotHandleRemoveSession(TDEAction::ActivationReason reason, TQt::ButtonState /* state */)
 {
-    if (reason == KAction::PopupMenuActivation
+    if (reason == TDEAction::PopupMenuActivation
         && tab_bar->pressedPosition() != -1)
     {
         slotRemoveSession(tab_bar->sessionIdForTabPosition(tab_bar->pressedPosition()));
@@ -650,9 +650,9 @@ void MainWindow::windowActivationChange(bool old_active)
         slotToggleState();
 }
 
-void MainWindow::slotHandleHorizontalSplit(KAction::ActivationReason reason, TQt::ButtonState /* state */)
+void MainWindow::slotHandleHorizontalSplit(TDEAction::ActivationReason reason, TQt::ButtonState /* state */)
 {
-    if (reason == KAction::PopupMenuActivation
+    if (reason == TDEAction::PopupMenuActivation
         && tab_bar->pressedPosition() != -1)
     {
         slotSplitHorizontally(tab_bar->sessionIdForTabPosition(tab_bar->pressedPosition()));
@@ -662,9 +662,9 @@ void MainWindow::slotHandleHorizontalSplit(KAction::ActivationReason reason, TQt
         slotSplitHorizontally();
 }
 
-void MainWindow::slotHandleVerticalSplit(KAction::ActivationReason reason, TQt::ButtonState /* state */)
+void MainWindow::slotHandleVerticalSplit(TDEAction::ActivationReason reason, TQt::ButtonState /* state */)
 {
-    if (reason == KAction::PopupMenuActivation
+    if (reason == TDEAction::PopupMenuActivation
         && tab_bar->pressedPosition() != -1)
     {
         slotSplitVertically(tab_bar->sessionIdForTabPosition(tab_bar->pressedPosition()));
@@ -675,9 +675,9 @@ void MainWindow::slotHandleVerticalSplit(KAction::ActivationReason reason, TQt::
 }
 
 
-void MainWindow::slotHandleRemoveTerminal(KAction::ActivationReason reason, TQt::ButtonState /* state */)
+void MainWindow::slotHandleRemoveTerminal(TDEAction::ActivationReason reason, TQt::ButtonState /* state */)
 {
-    if (reason == KAction::PopupMenuActivation
+    if (reason == TDEAction::PopupMenuActivation
         && tab_bar->pressedPosition() != -1)
     {
         slotRemoveTerminal(tab_bar->sessionIdForTabPosition(tab_bar->pressedPosition()));
@@ -724,7 +724,7 @@ TQRect MainWindow::getDesktopGeometry()
     TQRect result;
     result = desk_info.workArea();
 
-    KConfigGroup group(KGlobal::config(), "Windows");
+    TDEConfigGroup group(TDEGlobal::config(), "Windows");
 
     if (TQApplication::desktop()->isVirtualDesktop() &&
             group.readBoolEntry("XineramaEnabled", true) &&
@@ -765,7 +765,7 @@ void MainWindow::createMenu()
 {
     /* Creates the main menu. */
 
-    menu = new KPopupMenu();
+    menu = new TDEPopupMenu();
 
     menu->insertTitle(i18n("Help"));
 
@@ -777,7 +777,7 @@ void MainWindow::createMenu()
 
     actionCollection()->action(KStdAction::stdName(KStdAction::FullScreen))->plug(menu);
 
-    screen_menu = new KPopupMenu(menu);
+    screen_menu = new TDEPopupMenu(menu);
 
     if (TQApplication::desktop()->numScreens() > 1)
     {
@@ -785,11 +785,11 @@ void MainWindow::createMenu()
         connect(screen_menu, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetScreen(int)));
     }
 
-    width_menu = new KPopupMenu(menu);
+    width_menu = new TDEPopupMenu(menu);
     menu->insertItem(i18n("Width"), width_menu);
     connect(width_menu, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetWidth(int)));
 
-    height_menu = new KPopupMenu(menu);
+    height_menu = new TDEPopupMenu(menu);
     menu->insertItem(i18n("Height"), height_menu);
     connect(height_menu, TQT_SIGNAL(activated(int)), TQT_TQOBJECT(this), TQT_SLOT(slotSetHeight(int)));
 
@@ -828,7 +828,7 @@ void MainWindow::updateScreenMenu()
 
 void MainWindow::createSessionMenu()
 {
-    session_menu = new KPopupMenu();
+    session_menu = new TDEPopupMenu();
 
     actionCollection()->action("add_tab")->plug(session_menu);
     actionCollection()->action("add_tab_twohorizontal")->plug(session_menu);
@@ -909,7 +909,7 @@ void MainWindow::slotToggleState()
     if (timer.isActive())
         return;
 
-    KWinModule kwin(TQT_TQOBJECT(this));
+    KWinModule twin(TQT_TQOBJECT(this));
 
     if (state)
     {
@@ -1000,7 +1000,7 @@ void MainWindow::slotDecreaseHeight()
 
 void MainWindow::slotInitSkin()
 {
-    KConfig config(locate("appdata", Settings::skin() + "/title.skin"));
+    TDEConfig config(locate("appdata", Settings::skin() + "/title.skin"));
 
     config.setGroup("Border");
 
@@ -1058,7 +1058,7 @@ void MainWindow::moveEvent(TQMoveEvent* e)
     // mouse cursor is on, detect whether the screen number has
     // changed on this move event and update the internal set-
     // ting. Makes it play nice with the move-window-to-screen
-    // kwin shortcuts found in Lubos' Xinerama Improvements patch-
+    // twin shortcuts found in Lubos' Xinerama Improvements patch-
     // set.
 
     if (Settings::screen()
@@ -1071,7 +1071,7 @@ void MainWindow::moveEvent(TQMoveEvent* e)
         slotUpdateSize();
     }
 
-    KMainWindow::moveEvent(e);
+    TDEMainWindow::moveEvent(e);
 }
 
 void MainWindow::slotSetFullScreen(bool state)
@@ -1133,7 +1133,7 @@ void MainWindow::slotSetAccessKey()
 
     if (focus_policy == false) focus_policy = true;
 
-    KConfig config(CONFIG_FILE);
+    TDEConfig config(CONFIG_FILE);
 
     KKeyDialog::configure(global_key);
 
@@ -1149,7 +1149,7 @@ void MainWindow::slotSetControlKeys()
 
     if (focus_policy == false) focus_policy = true;
 
-    KConfig config(CONFIG_FILE);
+    TDEConfig config(CONFIG_FILE);
 
     KKeyDialog::configure(actionCollection());
 
@@ -1198,10 +1198,10 @@ void MainWindow::slotOpenSettingsDialog()
     if (focus_policy == false)
         focus_policy = true;
 
-    if (KConfigDialog::showDialog("settings"))
+    if (TDEConfigDialog::showDialog("settings"))
         return;
 
-    KConfigDialog* settings_dialog = new KConfigDialog(this, "settings", Settings::self());
+    TDEConfigDialog* settings_dialog = new TDEConfigDialog(this, "settings", Settings::self());
 
     GeneralSettings* general_settings = new GeneralSettings(settings_dialog, "General");
     settings_dialog->addPage(general_settings, i18n("General"), "package_settings");
@@ -1260,7 +1260,7 @@ void MainWindow::slotFirstRunDialogOK()
 
     if (first_run_dialog_page->shortcut() != global_key->shortcut("AccessKey"))
     {
-        KConfig config(CONFIG_FILE);
+        TDEConfig config(CONFIG_FILE);
         global_key->setShortcut("AccessKey", first_run_dialog_page->shortcut());
         global_key->updateConnections();
         global_key->writeSettings(&config);
@@ -1280,7 +1280,7 @@ void MainWindow::slotOpenAboutApp()
 {
     if (!about_app)
     {
-        about_app = new KAboutApplication(this, "About Yakuake");
+        about_app = new TDEAboutApplication(this, "About Yakuake");
         connect(about_app, TQT_SIGNAL(hidden()), TQT_TQOBJECT(this), TQT_SLOT(slotDialogFinished()));
     }
 
@@ -1296,7 +1296,7 @@ void MainWindow::slotOpenAboutKDE()
 {
     if (!about_kde)
     {
-        about_kde = new KAboutKDE(this, "About KDE");
+        about_kde = new TDEAboutKDE(this, "About KDE");
         connect(about_kde, TQT_SIGNAL(hidden()), TQT_TQOBJECT(this), TQT_SLOT(slotDialogFinished()));
     }
 
