@@ -42,7 +42,7 @@ Terminal::Terminal(TQWidget* parent, const char* name) : TQObject(parent, name)
     if (terminal_part != NULL)
     {
         terminal_widget = terminal_part->widget();
-        terminal_widget->setFocusPolicy(TQ_WheelFocus);
+        terminal_widget->setFocusPolicy(TQWidget::WheelFocus);
         terminal_interface = (TerminalInterface *) (terminal_part->tqt_cast("TerminalInterface"));
 
         connect(terminal_part, TQT_SIGNAL(destroyed()), this, TQT_SLOT(deleteLater()));
