@@ -19,7 +19,7 @@
 
 class TerminalSplitter : public TQSplitter
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
     public:
